/*
 * Copyright 2009 Red Hat, Inc.
 * Red Hat licenses this file to you under the Apache License, version
 * 2.0 (the "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *    http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied.  See the License for the specific language governing
 * permissions and limitations under the License.
 */
package org.jboss.as.integration.hornetq.management.jms;

import org.hornetq.core.server.HornetQServer;
import org.jboss.managed.api.annotation.*;

import java.lang.reflect.Method;

/**
 * @author <a href="mailto:andy.taylor@jboss.org">Andy Taylor</a>
 *         Created Mar 26, 2010
 */
@ManagementObject(componentType = @ManagementComponent(type = "JMSManage", subtype = "ServerManage"),
    properties = ManagementProperties.EXPLICIT, isRuntime = true)
public class JMSServerMO extends JMSManageMO
{
   public JMSServerMO(HornetQServer server)
   {
      super(server);   
   }

   @ManagementOperation(name = "getVersion", description = "returns the servers version")
   public String getVersion()
   {
      return jmsServerControl.getVersion();
   }

   @ManagementOperation(name = "getVersion", description = "returns the servers status")
   public boolean isStarted()
   {
      return jmsServerControl.isStarted();
   }

   @ManagementOperation(name = "invokeManagerOperation", description = "invokes a queues method",
       params = {
           @ManagementParameter(name = "name", description = "the name"),
           @ManagementParameter(name = "method", description = "the method"),
           @ManagementParameter(name = "params", description = "the method params")})
   public Object invokeManagerOperation(String name, String method, String[] params, String[] type) throws Exception
   {
      Class[] classes = getClassTypes(type);
      Method m = null;
      try
      {
         m = jmsServerControl.getClass().getMethod(method, classes);
         return m.invoke(jmsServerControl, getParams(params, classes));
      }
      catch (NoSuchMethodException e)
      {
         m = hornetQServerControl.getClass().getMethod(method, classes);
         return m.invoke(hornetQServerControl, getParams(params, classes));
      }

   }
}
